@@ -4,12 +4,13 @@ from django.conf import settings
 from django.http import HttpRequest
 from django.utils import timezone
 from ipware.ip import get_real_ip
+from jutil.email import send_email
 
 
 logger = logging.getLogger(__name__)
 
 
-class EnsureOriginMiddleware(object):
+class EnsureOriginMiddleware:
     """
     Ensures that META HTTP_ORIGIN is set.
     """
@@ -32,7 +33,7 @@ class EnsureOriginMiddleware(object):
         return response
 
 
-class LogExceptionMiddleware(object):
+class LogExceptionMiddleware:
     """
     Logs exception and sends email to admins about it.
     Uses list of emails from settings.ADMINS.
@@ -50,20 +51,19 @@ class LogExceptionMiddleware(object):
         :param request: HttpRequest
         :param e: Exception
         """
-        from jutil.email import send_email
-
         assert isinstance(request, HttpRequest)
         full_path = request.get_full_path()
         user = request.user
-        msg = '{full_path}\n{err} (IP={ip}, user={user}) {trace}'.format(full_path=full_path, user=user, ip=get_real_ip(request), err=e, trace=str(traceback.format_exc()))
+        msg = '{full_path}\n{err} (IP={ip}, user={user}) {trace}'.format(full_path=full_path, user=user,
+                                                                         ip=get_real_ip(request), err=e,
+                                                                         trace=str(traceback.format_exc()))
         logger.error(msg)
         hostname = request.get_host()
         if not settings.DEBUG and hostname != 'testserver':
             send_email(settings.ADMINS, 'Error @ {}'.format(hostname), msg)
-        return None
 
 
-class EnsureLanguageCookieMiddleware(object):
+class EnsureLanguageCookieMiddleware:
     """
     Ensures language cookie (by name settings.LANGUAGE_COOKIE_NAME) is set.
     Sets it as settings.LANGUAGE_CODE if missing.
@@ -89,7 +89,7 @@ class EnsureLanguageCookieMiddleware(object):
         return res
 
 
-class ActivateUserProfileTimezone(object):
+class ActivateUserProfileTimezone:
     """
     Uses 'timezone' string in request.user.profile to activate user-specific timezone.
     """
